Rename library and update build system
Change-Id: I78c6a412c5e2181e58649c0e0aa2aa2f97da16a1
diff --git a/src/schedule.hpp b/src/schedule.hpp
index a919767..d13c93a 100644
--- a/src/schedule.hpp
+++ b/src/schedule.hpp
@@ -2,31 +2,31 @@
/**
* Copyright (c) 2014-2018, Regents of the University of California
*
* This file is part of ndn-group-encrypt (Group-based Encryption Protocol for NDN).
* See AUTHORS.md for complete list of ndn-group-encrypt authors and contributors.
*
* ndn-group-encrypt is free software: you can redistribute it and/or modify it under the terms
* of the GNU General Public License as published by the Free Software Foundation,
* either version 3 of the License, or (at your option) any later version.
*
- * ndn-group-encrypt is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+ * NAC is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
* without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
* PURPOSE. See the GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License along with
- * ndn-group-encrypt, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
+ * NAC, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*
* @author Zhiyi Zhang <zhiyi@cs.ucla.edu>
*/
-#ifndef NDN_GEP_SCHEDULE_HPP
-#define NDN_GEP_SCHEDULE_HPP
+#ifndef NDN_NAC_SCHEDULE_HPP
+#define NDN_NAC_SCHEDULE_HPP
#include "common.hpp"
#include "repetitive-interval.hpp"
namespace ndn {
-namespace gep {
+namespace nac {
/**
* @brief Schedule is used to manage the time, which contains two sets of RepetitiveIntervals
@@ -39,7 +39,8 @@
public:
Schedule();
- explicit Schedule(const Block& block);
+ explicit
+ Schedule(const Block& block);
public:
template<encoding::Tag TAG>
@@ -78,7 +79,7 @@
mutable Block m_wire;
};
-} // namespace gep
+} // namespace nac
} // namespace ndn
-#endif // NDN_GEP_SCHEDULE_HPP
+#endif // NDN_NAC_SCHEDULE_HPP
@@ -2,31 +2,31 @@
* Copyright (c) 2014-2018, Regents of the University of California
*
- * This file is part of ndn-group-encrypt (Group-based Encryption Protocol for NDN).
- * See AUTHORS.md for complete list of ndn-group-encrypt authors and contributors.
+ * This file is part of NAC (Name-Based Access Control for NDN).
+ * See AUTHORS.md for complete list of NAC authors and contributors.
*
@@ -2,31 +2,31 @@
*
- * ndn-group-encrypt is free software: you can redistribute it and/or modify it under the terms
+ * NAC is free software: you can redistribute it and/or modify it under the terms
* of the GNU General Public License as published by the Free Software Foundation,
* either version 3 of the License, or (at your option) any later version.